==> smartclientcore7.5.6.zip: docs/constants/interfaces/interfaces/DeliverAd.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / DeliverAd

# Interface: DeliverAd

## Extends

- `CurrentAd`

## Properties

<a id="adbreakposition" name="adbreakposition"></a>

### adBreakPosition

> **adBreakPosition**: `number`

#### Inherited from

`CurrentAd.adBreakPosition`

***

<a id="adids" name="adids"></a>

### adIds

> **adIds**: (`null` \| `string`)[]

#### Inherited from

`CurrentAd.adIds`

***

<a id="adreinsertion" name="adreinsertion"></a>

### adReinsertion

> **adReinsertion**: `AdReinsertionModel`

#### Inherited from

`CurrentAd.adReinsertion`

***

<a id="adservingid" name="adservingid"></a>

### adServingId

> **adServingId**: `null` \| `string`

#### Inherited from

`CurrentAd.adServingId`

***

<a id="adtype" name="adtype"></a>

### adType

> **adType**: `string`

#### Inherited from

`CurrentAd.adType`

***

<a id="adverifications" name="adverifications"></a>

### adVerifications

> **adVerifications**: `any`

#### Inherited from

`CurrentAd.adVerifications`

***

<a id="adxml" name="adxml"></a>

### adXML

> **adXML**: `any`

#### Inherited from

`CurrentAd.adXML`

***

<a id="clickthroughurl" name="clickthroughurl"></a>

### clickThroughURL

> **clickThroughURL**: `string`

#### Inherited from

`CurrentAd.clickThroughURL`

***

<a id="closedcaptions" name="closedcaptions"></a>

### closedCaptions

> **closedCaptions**: [`ClosedCaption`](constants/interfaces/interfaces/ClosedCaption.md)[]

#### Inherited from

`CurrentAd.closedCaptions`

***

<a id="config" name="config"></a>

### config

> **config**: [`CoreConfig`](constants/interfaces/interfaces/CoreConfig.md)

#### Inherited from

`CurrentAd.config`

***

<a id="creativeclass" name="creativeclass"></a>

### creativeClass

> **creativeClass**: `any`

#### Inherited from

`CurrentAd.creativeClass`

***

<a id="creatives" name="creatives"></a>

### creatives

> **creatives**: `any`[]

#### Inherited from

`CurrentAd.creatives`

***

<a id="creativesarray" name="creativesarray"></a>

### creativesArray

> **creativesArray**: `any`

#### Inherited from

`CurrentAd.creativesArray`

***

<a id="currenttime" name="currenttime"></a>

### currentTime

> **currentTime**: `number`

#### Inherited from

`CurrentAd.currentTime`

***

<a id="duration" name="duration"></a>

### duration

> **duration**: `number`

#### Inherited from

`CurrentAd.duration`

***

<a id="enrichment" name="enrichment"></a>

### enrichment

> **enrichment**: `EnrichmentModel`

#### Inherited from

`CurrentAd.enrichment`

***

<a id="error" name="error"></a>

### error

> **error**: [`ErrorStatus`](constants/interfaces/interfaces/ErrorStatus.md)

#### Inherited from

`CurrentAd.error`

***

<a id="expectedadtype" name="expectedadtype"></a>

### expectedAdType

> **expectedAdType**: `string`

#### Inherited from

`CurrentAd.expectedAdType`

***

<a id="extensions" name="extensions"></a>

### extensions

> **extensions**: [`Extension`](constants/interfaces/interfaces/Extension.md)[]

#### Inherited from

`CurrentAd.extensions`

***

<a id="haserror" name="haserror"></a>

### hasError

> **hasError**: `boolean`

#### Inherited from

`CurrentAd.hasError`

***

<a id="icons" name="icons"></a>

### icons

> **icons**: `object`

#### Index Signature

 \[`key`: `string`\]: [`IconProgram`](constants/interfaces/interfaces/IconProgram.md)

#### Inherited from

`CurrentAd.icons`

***

<a id="id" name="id"></a>

### id

> **id**: `null` \| `string`

#### Inherited from

`CurrentAd.id`

***

<a id="ids" name="ids"></a>

### ids

> **ids**: (`null` \| `string`)[]

#### Inherited from

`CurrentAd.ids`

***

<a id="isexpanded" name="isexpanded"></a>

### isExpanded

> **isExpanded**: `boolean`

#### Inherited from

`CurrentAd.isExpanded`

***

<a id="isinteractive" name="isinteractive"></a>

### isInteractive

> **isInteractive**: `boolean`

#### Inherited from

`CurrentAd.isInteractive`

***

<a id="islinear" name="islinear"></a>

### isLinear

> **isLinear**: `boolean`

#### Inherited from

`CurrentAd.isLinear`

***

<a id="ispaused" name="ispaused"></a>

### isPaused

> **isPaused**: `boolean`

#### Inherited from

`CurrentAd.isPaused`

***

<a id="issimid" name="issimid"></a>

### isSIMID

> **isSIMID**: `boolean`

#### Inherited from

`CurrentAd.isSIMID`

***

<a id="isskippable" name="isskippable"></a>

### isSkippable

> **isSkippable**: `boolean`

#### Inherited from

`CurrentAd.isSkippable`

***

<a id="isvpaid" name="isvpaid"></a>

### isVPAID

> **isVPAID**: `boolean`

#### Inherited from

`CurrentAd.isVPAID`

***

<a id="propercreative" name="propercreative"></a>

### properCreative

> **properCreative**: `any`

#### Inherited from

`CurrentAd.properCreative`

***

<a id="publishermacros" name="publishermacros"></a>

### publisherMacros

> **publisherMacros**: `object`

#### Inherited from

`CurrentAd.publisherMacros`

***

<a id="remainingtime" name="remainingtime"></a>

### remainingTime

> **remainingTime**: `number`

#### Inherited from

`CurrentAd.remainingTime`

***

<a id="skipoffset" name="skipoffset"></a>

### skipOffset

> **skipOffset**: `number`

#### Inherited from

`CurrentAd.skipOffset`

***

<a id="title" name="title"></a>

### title

> **title**: `null` \| `string`

#### Inherited from

`CurrentAd.title`

***

<a id="trackingevents" name="trackingevents"></a>

### trackingEvents

> **trackingEvents**: `Record`\<`string`, `object`[]\>

***

<a id="universaladid" name="universaladid"></a>

### universalAdId

> **universalAdId**: [`UniversalAdId`](constants/interfaces/interfaces/UniversalAdId.md)

#### Inherited from

`CurrentAd.universalAdId`

***

<a id="universaladids" name="universaladids"></a>

### universalAdIds

> **universalAdIds**: [`UniversalAdId`](constants/interfaces/interfaces/UniversalAdId.md)[]

#### Inherited from

`CurrentAd.universalAdIds`

***

<a id="variant" name="variant"></a>

### variant

> **variant**: `string`

#### Inherited from

`CurrentAd.variant`

***

<a id="viewability" name="viewability"></a>

### viewability

> **viewability**: [`Viewability`](constants/interfaces/interfaces/Viewability.md)

#### Inherited from

`CurrentAd.viewability`

***

<a id="volume" name="volume"></a>

### volume

> **volume**: `number`

#### Inherited from

`CurrentAd.volume`

***

<a id="wrappers" name="wrappers"></a>

### wrappers

> **wrappers**: [`Wrapper`](constants/interfaces/interfaces/Wrapper.md)[]

#### Inherited from

`CurrentAd.wrappers`

==> smartclientcore7.6.0-dev.zip: docs/constants/interfaces/interfaces/DeliverAd.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / DeliverAd

# Interface: DeliverAd

## Extends

- `CurrentAd`

## Properties

<a id="adbreakposition" name="adbreakposition"></a>

### adBreakPosition

> **adBreakPosition**: `number`

#### Inherited from

`CurrentAd.adBreakPosition`

***

<a id="adids" name="adids"></a>

### adIds

> **adIds**: (`null` \| `string`)[]

#### Inherited from

`CurrentAd.adIds`

***

<a id="adreinsertion" name="adreinsertion"></a>

### adReinsertion

> **adReinsertion**: `AdReinsertionModel`

#### Inherited from

`CurrentAd.adReinsertion`

***

<a id="adservingid" name="adservingid"></a>

### adServingId

> **adServingId**: `null` \| `string`

#### Inherited from

`CurrentAd.adServingId`

***

<a id="adskippablestatechangesent" name="adskippablestatechangesent"></a>

### adSkippableStateChangeSent

> **adSkippableStateChangeSent**: `boolean`

#### Inherited from

`CurrentAd.adSkippableStateChangeSent`

***

<a id="adtrackers" name="adtrackers"></a>

### adTrackers

> **adTrackers**: `any`

***

<a id="adtype" name="adtype"></a>

### adType

> **adType**: `string`

#### Inherited from

`CurrentAd.adType`

***

<a id="adverifications" name="adverifications"></a>

### adVerifications

> **adVerifications**: `any`

#### Inherited from

`CurrentAd.adVerifications`

***

<a id="adxml" name="adxml"></a>

### adXML

> **adXML**: `any`

#### Inherited from

`CurrentAd.adXML`

***

<a id="clickthroughurl" name="clickthroughurl"></a>

### clickThroughURL

> **clickThroughURL**: `string`

#### Inherited from

`CurrentAd.clickThroughURL`

***

<a id="closedcaptions" name="closedcaptions"></a>

### closedCaptions

> **closedCaptions**: [`ClosedCaption`](constants/interfaces/interfaces/ClosedCaption.md)[]

#### Inherited from

`CurrentAd.closedCaptions`

***

<a id="config" name="config"></a>

### config

> **config**: [`CoreConfig`](constants/interfaces/interfaces/CoreConfig.md) \| [`URLConfig`](constants/interfaces/interfaces/URLConfig.md)

#### Inherited from

`CurrentAd.config`

***

<a id="creativeclass" name="creativeclass"></a>

### creativeClass

> **creativeClass**: `any`

#### Inherited from

`CurrentAd.creativeClass`

***

<a id="creatives" name="creatives"></a>

### creatives

> **creatives**: `any`[]

#### Inherited from

`CurrentAd.creatives`

***

<a id="creativesarray" name="creativesarray"></a>

### creativesArray

> **creativesArray**: `any`

#### Inherited from

`CurrentAd.creativesArray`

***

<a id="currentclip" name="currentclip"></a>

### currentClip

> **currentClip**: `number`

***

<a id="currentcommercial" name="currentcommercial"></a>

### currentCommercial

> **currentCommercial**: `number`

***

<a id="currentpodsequencing" name="currentpodsequencing"></a>

### currentPodSequencing

> **currentPodSequencing**: `number`

***

<a id="currenttime" name="currenttime"></a>

### currentTime

> **currentTime**: `number`

#### Inherited from

`CurrentAd.currentTime`

***

<a id="duration" name="duration"></a>

### duration

> **duration**: `number`

#### Inherited from

`CurrentAd.duration`

***

<a id="enrichment" name="enrichment"></a>

### enrichment

> **enrichment**: `EnrichmentModel`

#### Inherited from

`CurrentAd.enrichment`

***

<a id="error" name="error"></a>

### error

> **error**: [`ErrorStatus`](constants/interfaces/interfaces/ErrorStatus.md)

#### Inherited from

`CurrentAd.error`

***

<a id="expectedadtype" name="expectedadtype"></a>

### expectedAdType

> **expectedAdType**: `string`

#### Inherited from

`CurrentAd.expectedAdType`

***

<a id="extensions" name="extensions"></a>

### extensions

> **extensions**: [`Extension`](constants/interfaces/interfaces/Extension.md)[]

#### Inherited from

`CurrentAd.extensions`

***

<a id="fallbackonnoad" name="fallbackonnoad"></a>

### fallbackOnNoAd

> **fallbackOnNoAd**: `boolean`

***

<a id="handleclickthrough" name="handleclickthrough"></a>

### handleClickThrough

> **handleClickThrough**: `undefined` \| `boolean`

#### Inherited from

`CurrentAd.handleClickThrough`

***

<a id="haserror" name="haserror"></a>

### hasError

> **hasError**: `boolean`

#### Inherited from

`CurrentAd.hasError`

***

<a id="icons" name="icons"></a>

### icons

> **icons**: `object`

#### Index Signature

 \[`key`: `string`\]: [`IconProgram`](constants/interfaces/interfaces/IconProgram.md)

#### Inherited from

`CurrentAd.icons`

***

<a id="id" name="id"></a>

### id

> **id**: `null` \| `string`

#### Inherited from

`CurrentAd.id`

***

<a id="ids" name="ids"></a>

### ids

> **ids**: (`null` \| `string`)[]

#### Inherited from

`CurrentAd.ids`

***

<a id="isexpanded" name="isexpanded"></a>

### isExpanded

> **isExpanded**: `boolean`

#### Inherited from

`CurrentAd.isExpanded`

***

<a id="isinteractive" name="isinteractive"></a>

### isInteractive

> **isInteractive**: `boolean`

#### Inherited from

`CurrentAd.isInteractive`

***

<a id="islinear" name="islinear"></a>

### isLinear

> **isLinear**: `boolean`

#### Inherited from

`CurrentAd.isLinear`

***

<a id="ispaused" name="ispaused"></a>

### isPaused

> **isPaused**: `boolean`

#### Inherited from

`CurrentAd.isPaused`

***

<a id="issimid" name="issimid"></a>

### isSIMID

> **isSIMID**: `boolean`

#### Inherited from

`CurrentAd.isSIMID`

***

<a id="isskippable" name="isskippable"></a>

### isSkippable

> **isSkippable**: `boolean`

#### Inherited from

`CurrentAd.isSkippable`

***

<a id="isvpaid" name="isvpaid"></a>

### isVPAID

> **isVPAID**: `boolean`

#### Inherited from

`CurrentAd.isVPAID`

***

<a id="minsuggestedduration" name="minsuggestedduration"></a>

### minSuggestedDuration

> **minSuggestedDuration**: `number`

***

<a id="propercreative" name="propercreative"></a>

### properCreative

> **properCreative**: `any`

#### Inherited from

`CurrentAd.properCreative`

***

<a id="publishermacros" name="publishermacros"></a>

### publisherMacros

> **publisherMacros**: `object`

#### Inherited from

`CurrentAd.publisherMacros`

***

<a id="remainingtime" name="remainingtime"></a>

### remainingTime

> **remainingTime**: `number`

#### Inherited from

`CurrentAd.remainingTime`

***

<a id="replaced" name="replaced"></a>

### replaced

> **replaced**: `boolean`

#### Inherited from

`CurrentAd.replaced`

***

<a id="sequence" name="sequence"></a>

### sequence

> **sequence**: `number`

***

<a id="skipoffset" name="skipoffset"></a>

### skipOffset

> **skipOffset**: `number`

#### Inherited from

`CurrentAd.skipOffset`

***

<a id="skipoffsetvalue" name="skipoffsetvalue"></a>

### skipOffsetValue

> **skipOffsetValue**: `number`

***

<a id="title" name="title"></a>

### title

> **title**: `null` \| `string`

#### Inherited from

`CurrentAd.title`

***

<a id="trackingevents" name="trackingevents"></a>

### trackingEvents

> **trackingEvents**: [`TrackingEvents`](constants/interfaces/interfaces/TrackingEvents.md)

***

<a id="type" name="type"></a>

### type

> **type**: `string`

#### Inherited from

`CurrentAd.type`

***

<a id="universaladid" name="universaladid"></a>

### universalAdId

> **universalAdId**: [`UniversalAdId`](constants/interfaces/interfaces/UniversalAdId.md)

#### Inherited from

`CurrentAd.universalAdId`

***

<a id="universaladids" name="universaladids"></a>

### universalAdIds

> **universalAdIds**: [`UniversalAdId`](constants/interfaces/interfaces/UniversalAdId.md)[]

#### Inherited from

`CurrentAd.universalAdIds`

***

<a id="variant" name="variant"></a>

### variant

> **variant**: `string`

#### Inherited from

`CurrentAd.variant`

***

<a id="viewability" name="viewability"></a>

### viewability

> **viewability**: [`Viewability`](constants/interfaces/interfaces/Viewability.md)

#### Inherited from

`CurrentAd.viewability`

***

<a id="volume" name="volume"></a>

### volume?

> `optional` **volume**: `number`

#### Inherited from

`CurrentAd.volume`

***

<a id="wrappers" name="wrappers"></a>

### wrappers

> **wrappers**: [`Wrapper`](constants/interfaces/interfaces/Wrapper.md)[]

#### Inherited from

`CurrentAd.wrappers`
